using System;
using System.IO;
using System.IO.Packaging;
using System.Xml;
using System.Xml.XPath;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace ExtractAllTextFromWordDoc
{
  public partial class Form1 : Form
  {

    private const string documentRelationshipType = @"http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
    private const string wordprocessingML = @"http://schemas.openxmlformats.org/wordprocessingml/2006/main";

    public Form1()
    {
      InitializeComponent();
    }

    private void btnStart_Click(object sender, EventArgs e)
    {
      treeView1.Nodes.Clear();
      dlgFileOpen.Filter = "Word 2007 Files (*.docx)|*.docx";
      if (dlgFileOpen.ShowDialog() == DialogResult.OK)
      {
        GetAllTextFromWordDoc(dlgFileOpen.FileName);
        treeView1.ExpandAll();
      }
    }


    private void GetAllTextFromWordDoc(string fName)
    {
      Uri docUri = null;
      PackagePart docPart = null;

      using (Package xPack = Package.Open(fName, FileMode.Open, FileAccess.Read))
      {
        foreach (PackageRelationship relationship in xPack.GetRelationshipsByType(documentRelationshipType))
        {
          docUri = PackUriHelper.ResolvePartUri(new Uri("/", UriKind.Relative), relationship.TargetUri);  // relationship.TargetUri = "word/document.xml"
          docPart = xPack.GetPart(docUri);
          break;
        }

        XmlDocument xDoc = new XmlDocument();
        xDoc.Load(docPart.GetStream(FileMode.Open, FileAccess.Read));
        
        XmlNamespaceManager nsmgr = new XmlNamespaceManager(xDoc.NameTable);
        nsmgr.AddNamespace("w", wordprocessingML);

        XPathNavigator nav = xDoc.CreateNavigator();
        XPathNodeIterator iter = nav.Select("//w:p", nsmgr);

        TreeNode root = treeView1.Nodes.Add(fName);
        while(iter.MoveNext()) 
        {
          string s = iter.Current.Value;
          if (s == string.Empty)
            s = "[ empty paragraph ]";
          TreeNode p = root.Nodes.Add(s);
        }
      }
    }

  }
}